@@ -3,8 +3,8 @@
 import mimetypes
 import os
 import sys
-import time
 import re
+import math
 
 from pyredactkit.identifiers import Identifier
 
@@ -88,6 +88,7 @@ class Redactor:
         Returns:
             redacted_line (str): redacted line
         """
+        # Refactor this to loop through and check for option.
         redacted_line = ''
         if option in ("dns", "domain"):
             dns = id_object.regexes[1]['pattern']
@@ -133,7 +134,7 @@ class Redactor:
             savedir (str): [Optional] directory to place results
 
         Returns:
-            None
+            Creates redacted file.
         """
         count = 0
         try:
@@ -195,3 +196,50 @@ class Redactor:
             os.remove(f"{savedir}redacted_{os.path.basename(filename)}")
             print("[ - ] Removed incomplete redact file")
             sys.exit("[ - ] Unable to read file")
+
+    def process_report(self, filename):
+        """Function to process calculate and generate report of man hour saved.
+        Args:
+            filename (str): File to count the words
+
+        Returns:
+            Creates a report on estimated man hours/minutes saved.
+        """
+        try:
+            # Open a file read pointer as target_file
+            with open(filename, encoding="utf-8") as target_file:
+                text_chunk = target_file.read()
+
+                # Words per minute
+                WPM = 75
+
+                word_length = 5
+                total_words = 0
+                for current_text in text_chunk:
+                    total_words += len(current_text)/word_length
+
+                total_words = math.ceil(total_words)
+
+                # Divide total words by words per minute read to get minutes and hour estimate.
+                reading_minutes = math.ceil(total_words/WPM)
+                reading_hours = math.floor(reading_minutes/60)
+
+                word_report = f"[ + ] Estimated total words : {total_words}"
+                minutes_saved = f"[ + ] Estimated total minutes saved : {reading_minutes}"
+                man_hours_saved = f"[ + ] Estimated total man hours saved : {reading_hours}"
+
+                # Open a file write pointer as result
+                with open(
+                    f"manhours_saved_{os.path.basename(filename)}",
+                    "w",
+                    encoding="utf-8",
+                ) as result:
+                    result.write(word_report + "\n" +
+                                 minutes_saved + "\n" + man_hours_saved)
+                    print(
+                        f"[ + ] Estimated man hours saved report saved as manhours_saved_{os.path.basename(filename)}")
+
+        except UnicodeDecodeError:
+            os.remove(f"manhour_saved_report_{os.path.basename(filename)}")
+            print("[ - ] Removed incomplete report")
+            sys.exit("[ - ] Unable to read target file")
